@@ -223,7 +223,7 @@ mvrt.test <- function(data, obj=NULL, block, tolog=FALSE, nc.min=1, nc.max=30, p
 #                                      span=0.75,
 #                                      degree=2,
 #                                      family="gaussian",
-#                                      title="",
+#                                      title="Cluster Diagnostic Plots",
 #                                      device=NULL,
 #                                      file="Cluster Diagnostic Plots",
 #                                      path=getwd()
@@ -251,7 +251,7 @@ cluster.diagnostic <- function(obj,
                                span=0.75,
                                degree=2,
                                family="gaussian",
-                               title="",
+                               title="Cluster Diagnostic Plots",
                                device=NULL,
                                file="Cluster Diagnostic Plots",
                                path=getwd(),
@@ -352,7 +352,7 @@ cluster.diagnostic <- function(obj,
 # Usage         :
 ################
 #                   target.diagnostic(obj,
-#                                     title="",
+#                                     title="Target Moments Diagnostic Plots",
 #                                     device=NULL,
 #                                     file="Target Moments Diagnostic Plots",
 #                                     path=getwd(),
@@ -377,7 +377,7 @@ cluster.diagnostic <- function(obj,
 ##########################################################################################################################################
 
 target.diagnostic <- function(obj,
-                              title="",
+                              title="Target Moments Diagnostic Plots",
                               device=NULL,
                               file="Target Moments Diagnostic Plots",
                               path=getwd(),
@@ -506,7 +506,7 @@ target.diagnostic <- function(obj,
 #                                            span=0.5,
 #                                            degree=2,
 #                                            family="gaussian",
-#                                            title="",
+#                                            title="Stabilization Diagnostic Plots",
 #                                            device=NULL,
 #                                            file="Stabilization Diagnostic Plots",
 #                                            path=getwd(),
@@ -534,7 +534,7 @@ stabilization.diagnostic <- function(obj,
                                      span=0.5,
                                      degree=2,
                                      family="gaussian",
-                                     title="",
+                                     title="Stabilization Diagnostic Plots",
                                      device=NULL,
                                      file="Stabilization Diagnostic Plots",
                                      path=getwd(),
@@ -605,7 +605,7 @@ stabilization.diagnostic <- function(obj,
 ################
 #                   normalization.diagnostic(obj,
 #                                            pal,
-#                                            title="",
+#                                            title="Normalization Diagnostic Plots",
 #                                            device=NULL,
 #                                            file="Normalization Diagnostic Plots",
 #                                            path=getwd(),
@@ -631,7 +631,7 @@ stabilization.diagnostic <- function(obj,
 
 normalization.diagnostic <- function(obj,
                                      pal,
-                                     title="",
+                                     title="Normalization Diagnostic Plots",
                                      device=NULL,
                                      file="Normalization Diagnostic Plots",
                                      path=getwd(),
